Title: Book Review: Cailin O'Connor's <em>The Origins of Unfairness: Social Categories and Cultural Evolution</em>
Date: 2020-01-20 22:20
Category: commentary
Tags: categorization, feminism, game theory, review (book)

[This is a _super-great book_](https://global.oup.com/academic/product/the-origins-of-unfairness-9780198789970) about the cultural evolutionary game theory of gender roles! (And also stuff like race and religion and caste, I guess, but I'm ignoring that because I haven't gotten around to broadening the topic scope of this blog yet.) I am _unreasonably excited about this book_ for supplying the glue of _analytical rigor_ to a part of my world-model that had previously been held together by threads of mere handwaving! (Three years ago on this blog, I wrote, ["social-role defaults are inevitably going to accrete around [sex differences]"](/2017/Feb/a-beacon-through-the-darkness-or-getting-it-right-the-first-time/#views-have-changed), but I didn't, and couldn't, have told you _how and why_ in a form suitable for verification by computer simulation.)

In this blog post, I'm going to summarize what I learned from _Origins of Unfairness_ in my own words, but if you want to be a serious intellectual who actually reads grown-up books rather than relying on some pseudonymous _nobody's_ blog summary, you should [go buy the source material](https://www.amazon.com/dp/B07V5Q6R62/)!

-------

A puzzle: every human culture has gender roles and a substantial amount of division of labor by sex. From _within_ a particular culture, it might be tempting to "essentialize" these differences, to think that certain kinds of tasks inherently belong in the separate spheres of women or men, as ordained by the local religion's gods (or perhaps "evolution" if your local religion is pop-evopsych rather than real-evopsych). But anthropologists know that there's huge cross-cultural variation as to the details of what tasks are assigned to which sex. There are some regularities: things like big-game hunting and metalworking are always male tasks, and things like spinning, dairying, and primary child care are "women's work." But there are also a lot of differences: the task of making ropes or pottery is gendered _within_ a culture, but different cultures end up making different assignments.

What's going on here? Why divide labor by sex when either sex is capable of doing the job? Why not let individuals choose their own destinies, independently of how their genitals are shaped?

Observe that the [division and specialization of labor](https://en.wikipedia.org/wiki/Division_of_labour) is a [coordination problem](https://www.lesswrong.com/posts/9QxnfMYccz9QRgZ5z/the-costly-coordination-mechanism-of-common-knowledge#Coordination_Problems): there are many ways to try to produce stuff, but Society is richer when people choose ways that "fit together": our tribe is more likely to survive if I hunt and you gather _or_ you hunt and I gather, rather than if we try to both hunt (too much variance) or both gather (not enough protein). Moreover, the division of labor is a _complementary_ coordination problem, where we want different people do _different_ things that fit together (like hunting and gathering in a nomadic society, or cooking and cleaning in a household), in contrast to _correlative_ coordination problems where we want people to all end up doing the _same_ thing that fits together (like driving on the right side of the road, or meeting [at noon at the information booth at Grand Central Station](/2019/Oct/self-identity-is-a-schelling-point/#schelling-point)).

Consider a population of agents that meet in pairs and play a complementary coordination game, like ballroom dancers that need to decide [who should lead and who should follow](https://en.wikipedia.org/wiki/Lead_and_follow). It's kind of a pain if every single pair has to separately negotiate roles every time they meet! But if the agents come in two equally numerous _types_ (say, "women" and "men"), then the problem is easy: either of the [conventions](https://plato.stanford.edu/entries/convention/) "men lead, women follow" or "women lead, men follow" solves the problem for everyone!

Of course, "women and men dancing" is just an illustrative example as far as the _theory_ is concerned: the "types" here are just opaque tags that separate otherwise-identical abstract agents into groups. In particular, types are _not_ strategies. In terms of the dancing game, the _strategies_ "lead" and "follow" can't be types: rather, the arbitrary "men" and "women" tags (which might as well be [suggestively-named Lisp tokens](https://www.readthesequences.com/Truly-Part-Of-You)) are a symmetry-breaking hack that lets us turn _many_ complementary coordination games (for _every pair_, who should lead?) into a _single_ correlative coordination game (for the whole population, are we using the "men lead" or the "women lead" convention?).

Nor does there need to be a central "dance caller" who specifies which convention the population should follow. If strategies that are more successful are more frequently _imitated_ via social learning, conventions can arise from a process of cultural evolution: in a world where most men happen to lead, women learn to follow in order to have a successful dance, and the population gets swept in to the "men lead" convention. A convention's [basin of attraction](http://www.scholarpedia.org/article/Basin_of_attraction) is the set of initial population conditions that lead to the evolution of that convention. When there are many possible equilibria with roughly-equal-sized basins of attraction, the outcome is highly "conventional": things could have easily been otherwise given different initial conditions. (And can even be said to _contain more information_: "more possible outcomes" and "equally-probable outcomes" are what maximize [entropy](https://en.wikipedia.org/wiki/Entropy_(information_theory)).) Situations with fewer, unequally-sized basins of attraction are more "functional": the outcome is mostly determined by the game itself.

And that's where gender roles come from! In a Society facing complementary coordination problems in production, gender is _the symmetry-breaker around which conventions form_. And if skills need to be trained long before they get put into production, that shapes early socialization—in a Society where women do "women's work" to complement "men's work", they're raised to start practicing it as girls.

This is also where gender _inequality_ comes from. In game theory models _without_ types, all agents get the same payoffs in equilibrium. (Because if they didn't, then some strategy must pay better than others—which means more agents will copy it until it doesn't.)

With types, this is no longer true: the population can settle on equilibria that favor the interests of one type over another (but are better for everyone than the absence of coordination), like an "always Bach" convention in [the Bach–Stravinsky game](https://en.wikipedia.org/wiki/Battle_of_the_sexes_(game_theory)), or in the aggregation of [_many_ games that the type tags are being used for](/2019/Dec/more-schelling/).

This is especially true if we drop the assumption that the type "tags" have no in-game significance (other than being visible for coordination) and introduce an asymmetric payoff matrix. Consider the Nash bargaining game: two agents have to decide how to divide a pie with 10 slices, but if their demands are incompatible (like when I demand 7 slices and you also demand 7 slices, but 7 + 7 = 14 is greater than 10), then the pie explodes, and no one gets any pie. If different types of agents have different fallback options, that affects their incentives in the bargaining game: if you wouldn't have anything to eat if you didn't get any pie, then you might want to make a conservative demand, like 3 slices, in order to ensure that you get _some_ pie even if it turns out that I'm a greedy jerk who demands 7 slices. But if I have a sandwich that's as valuable to me as 2½ slices of pie, then I'm not particularly worried about you being a greedy jerk who demands 7 slices: to me, the difference between a successful 3-slice demand and failing to make a deal at all is only half a slice, which gives me an incentive to demand more, because I have less to lose than you if bargaining fails.

This kind of dynamic explains [the differences in women's roles between patriarchal "plow cultures" (in which men do agriculture with plows) and non-patriarchal "hoe cultures" (in which women do horticulture with hoes)](https://srconstantin.wordpress.com/2017/09/13/hoe-cultures-a-type-of-non-patriarchal-society/): a coordination equilibrium in which Society's primary means of sustenance is considered "women's work" gives women more negotiating power _as a class_. (Even when individual women in a [patriarchal](https://srconstantin.wordpress.com/2017/09/12/patriarchy-is-the-problem/) Society have high privilege (_e.g._, earning power), they're still women as far as conventions are concerned.)

The path of cultural evolution is affected not only by the types' bargaining power: the relative _speed_ of adaptation between types can matter, too! The [Red Queen hypothesis](https://en.wikipedia.org/wiki/Red_Queen_hypothesis) describes an evolutionary advantage to a species that can evolve quickly, the better to keep up in an evolutionary arms race against parasites. (As it happens, this may have been a key factor in the evolution of sexual reproduction—the reason, along with the [dynamic instability of equal-sized gametes](http://www.evolutionary-ecology.com/abstracts/v01/1021.html), that "females" and "males" even exist to begin with, rather than all organisms being asexual clones.) But in bargaining-like situations, there can be a "Red King" effect in which there's an advantage in evolving _slowly_. Much like how visibly throwing away your steering wheel is an advantage in [the game of Chicken](https://en.wikipedia.org/wiki/Chicken_(game)) (that precomitment forcing your opponent to swerve in response), the type that is slower to adapt to its "counterparty" type is effectively more resistant to its bargaining demands. As O'Connor puts it, "we can think of a fast-evolving species as swerving in evolutionary time."

Similarly, when a minority group (for example, women in a male-dominated workplace) interacts with a majority, a large fraction of a minority group member's interactions will be with members of the majority: the minority learns to adapt to the majority much faster than _vice versa_, placing the evolutionarily implicit norm negotiation on the majority's terms.

-----

A sign of high-integrity scholarship is when the [positive](https://en.wikipedia.org/wiki/Positive_statement) insights contained in a work can be appreciated independently of the author's normative agenda (if any). O'Connor, like me—at least, I _hope_ my self-identification in this matter is still valid, although the reader will ultimately judge that for herself—writes from a position of having a [glorious vision of gender equality](/2017/Dec/theres-a-land-that-i-see-or-the-spirit-of-intervention/) as [Something to Protect](/2019/Jul/the-source-of-our-power/), her mighty pen wielded in the service of that ideal in an act of heroic scholarship.

But having Something to Protect is the same thing as having something in danger. This is—as mathematical sociology treatises go—a very _dark_ book. O'Connor repeatedly emphasizes that the theory presented in the book shows how inequality can emerge _and persist_ under _very_ minimal conditions—with "no bias in [the] model, no stereotype threat, not much psychology in general"—in contrast to theories that present injustice as the consequence of unique malice or prejudice, rather than _mathematics_.

"Ultimately," she writes, "I will present a picture in which social justice is an endless battle. The forces of cultural evolution can pull populations towards inequity, and combating those forces requires constant vigilance." The book concludes, "The battle for social justice is against a hydra that grows a new head each time any one is cut off."

When I imagine an intelligent arch-reactionary reading _Origins of Unfairness_ (perhaps [twiddling his mustache](https://tvtropes.org/pmwiki/pmwiki.php/Main/DastardlyWhiplash) during an hour of study between a 2:30 [dog-kicking appointment](https://tvtropes.org/pmwiki/pmwiki.php/Main/KickTheDog) and 4 o'clock [advocacy of a Trump _coup d'état_](https://blog.jim.com/politics/the-likely-shape-of-a-trump-autocoup/)), I see him nodding along thoughtfully at the lucid prose explaining the underlying game theory insights (in between cringing at the occasional Judith Butler and stereotype-threat cites). That man, in the service of callously protecting his personal power and privilege, might construe _Origins_ as "supporting" _his_ ideology.

"Bwah-ha-ha!" he laughs maniacally. "I already knew that feminism was doomed simply due to the nature and meaning of male and female—but I had no idea it was _further_ doomed as a result of the _cultural evolutionary game theory of complementary coordination problems!_ And this, from one of the corrupt leftist establishment's own scholaresses! Priceless!"

_That's how you know it's a good book_. The map that reflects the territory is equally useful to good people and to bad men. Good and evil—as _we_ would define those terms—exist in the same material universe, whose exceptionless physical laws contain no provision for biologically _and culturally_ evolved human notions of mercy or fairness. The long arc of the moral universe points, not towards justice, but towards maximum entropy—just like [the arrow of time in every other universe](https://en.wikipedia.org/wiki/Entropy_(arrow_of_time)).

A lesser scholar, flinching from this terrible truth, might have seen fit to fudge their results, to [select](https://www.lesswrong.com/posts/DoPo4PDjgSySquHX8/heads-i-win-tails-never-heard-of-her-or-selective-reporting) their modeling assumptions to present a softer narrative, something that would make better propaganda for the Blue Team ...

It wouldn't have worked. I mean, it probably would have worked _as propaganda_, but it wouldn't have worked in the sense of [my dream about the use of maps](/2019/Aug/the-social-construction-of-reality-and-the-sheer-goddamned-pointlessness-of-reason/#a-dream-about-the-use-of-maps)—as scholarship, a beacon through the darkness, showing us the way to start to repair the world we actually live in, and not only the appearance of it.
